<a name="hWTeg"></a>

# 1、美国

北美洲国家<br />美利坚合众国（The United States of America），简称美国，首都[华盛顿](https://baike.baidu.com/item/%E5%8D%8E%E7%9B%9B%E9%A1%BF/374?fromModule=lemma_inlink)。位于[北美洲](https://baike.baidu.com/item/%E5%8C%97%E7%BE%8E%E6%B4%B2/135465?fromModule=lemma_inlink)中部，北与[加拿大](https://baike.baidu.com/item/%E5%8A%A0%E6%8B%BF%E5%A4%A7/145973?fromModule=lemma_inlink)接壤，南靠[墨西哥湾](https://baike.baidu.com/item/%E5%A2%A8%E8%A5%BF%E5%93%A5%E6%B9%BE/318506?fromModule=lemma_inlink)，西临[太平洋](https://baike.baidu.com/item/%E5%A4%AA%E5%B9%B3%E6%B4%8B/118304?fromModule=lemma_inlink)，东濒[大西洋](https://baike.baidu.com/item/%E5%A4%A7%E8%A5%BF%E6%B4%8B/10883?fromModule=lemma_inlink)。大部分地区属[大陆性气候](https://baike.baidu.com/item/%E5%A4%A7%E9%99%86%E6%80%A7%E6%B0%94%E5%80%99/409932?fromModule=lemma_inlink)，南部属[亚热带气候](https://baike.baidu.com/item/%E4%BA%9A%E7%83%AD%E5%B8%A6%E6%B0%94%E5%80%99/9881906?fromModule=lemma_inlink)，地形总体西高东低，自然资源丰富，矿产资源总探明储量居世界首位。 [18]总面积937万平方千米，[海岸线](https://baike.baidu.com/item/%E6%B5%B7%E5%B2%B8%E7%BA%BF/10975?fromModule=lemma_inlink)长22680千米，美国共分为50个州和1个特区（[哥伦比亚特区](https://baike.baidu.com/item/%E5%93%A5%E4%BC%A6%E6%AF%94%E4%BA%9A%E7%89%B9%E5%8C%BA/3347103?fromModule=lemma_inlink)），有3143个县。截至2023年2月，美国总人口约3.33亿，非拉美裔白人占57.8%，居民大多信奉[基督教](https://baike.baidu.com/item/%E5%9F%BA%E7%9D%A3%E6%95%99/222408?fromModule=lemma_inlink)及天主教，通用[英语](https://baike.baidu.com/item/%E8%8B%B1%E8%AF%AD/109997?fromModule=lemma_inlink)。 [1]<br />美国原为[印第安人](https://baike.baidu.com/item/%E5%8D%B0%E7%AC%AC%E5%AE%89%E4%BA%BA/254718?fromModule=lemma_inlink)聚居地。15世纪末，[西班牙](https://baike.baidu.com/item/%E8%A5%BF%E7%8F%AD%E7%89%99/148941?fromModule=lemma_inlink)、[荷兰](https://baike.baidu.com/item/%E8%8D%B7%E5%85%B0/190469?fromModule=lemma_inlink)、[法国](https://baike.baidu.com/item/%E6%B3%95%E5%9B%BD/1173384?fromModule=lemma_inlink)、[英国](https://baike.baidu.com/item/%E8%8B%B1%E5%9B%BD/144602?fromModule=lemma_inlink)等开始向北美移民。到1773年，英已建立13个殖民地。1775年，爆发[独立战争](https://baike.baidu.com/item/%E7%8B%AC%E7%AB%8B%E6%88%98%E4%BA%89/5250?fromModule=lemma_inlink)。1776年7月4日，通过《[独立宣言](https://baike.baidu.com/item/%E7%8B%AC%E7%AB%8B%E5%AE%A3%E8%A8%80/53146?fromModule=lemma_inlink)》，正式宣布建立美利坚合众国。1787年，制定[联邦宪法](https://baike.baidu.com/item/%E8%81%94%E9%82%A6%E5%AE%AA%E6%B3%95/9751203?fromModule=lemma_inlink)，南方为[蓄奴州](https://baike.baidu.com/item/%E8%93%84%E5%A5%B4%E5%B7%9E/3356720?fromModule=lemma_inlink)，北方为[自由州](https://baike.baidu.com/item/%E8%87%AA%E7%94%B1%E5%B7%9E/784885?fromModule=lemma_inlink)。1865年[南北战争](https://baike.baidu.com/item/%E5%8D%97%E5%8C%97%E6%88%98%E4%BA%89/631932?fromModule=lemma_inlink)结束，美国开始全面实行资本主义。建国后的领土几乎扩张了10倍。 [1]<br />美国是高度发达的现代化国家，其[国内生产总值](https://baike.baidu.com/item/%E5%9B%BD%E5%86%85%E7%94%9F%E4%BA%A7%E6%80%BB%E5%80%BC/31864?fromModule=lemma_inlink)居世界首位，具有世界规模最大和最发达的现代化市场经济。工业生产保持稳定，信息、生物等高科技产业发展迅速。美国法律制度健全，市场体系完善，营商环境良好，基础设施发达，在市场容量、科技实力、教育创新、劳动生产率等方面稳居全球领先地位。2022年，美国GDP为25.5万亿美元。 [1]美国是[联合国安全理事会常任理事国](https://baike.baidu.com/item/%E8%81%94%E5%90%88%E5%9B%BD%E5%AE%89%E5%85%A8%E7%90%86%E4%BA%8B%E4%BC%9A%E5%B8%B8%E4%BB%BB%E7%90%86%E4%BA%8B%E5%9B%BD/7952300?fromModule=lemma_inlink)，也是[北大西洋公约组织](https://baike.baidu.com/item/%E5%8C%97%E5%A4%A7%E8%A5%BF%E6%B4%8B%E5%85%AC%E7%BA%A6%E7%BB%84%E7%BB%87/508108?fromModule=lemma_inlink)、[世界贸易组织](https://baike.baidu.com/item/%E4%B8%96%E7%95%8C%E8%B4%B8%E6%98%93%E7%BB%84%E7%BB%87/150837?fromModule=lemma_inlink)、[亚太经济合作组织](https://baike.baidu.com/item/%E4%BA%9A%E5%A4%AA%E7%BB%8F%E6%B5%8E%E5%90%88%E4%BD%9C%E7%BB%84%E7%BB%87/424786?fromModule=lemma_inlink)等[国际组织](https://baike.baidu.com/item/%E5%9B%BD%E9%99%85%E7%BB%84%E7%BB%87/261053?fromModule=lemma_inlink)成员国，其[政治](https://baike.baidu.com/item/%E6%94%BF%E6%B2%BB/169778?fromModule=lemma_inlink)、[外交](https://baike.baidu.com/item/%E5%A4%96%E4%BA%A4/18817?fromModule=lemma_inlink)、[经济](https://baike.baidu.com/item/%E7%BB%8F%E6%B5%8E/403149?fromModule=lemma_inlink)、[文化](https://baike.baidu.com/item/%E6%96%87%E5%8C%96/23624?fromModule=lemma_inlink)等领域对世界均有较强影响力。 [18]
<a name="bvbTQ"></a>

## 1.1、行政区划

美国全国共分50个州和1个特区（哥伦比亚特区），有3143个县。联邦领地包括波多黎各和[北马里亚纳](https://baike.baidu.com/item/%E5%8C%97%E9%A9%AC%E9%87%8C%E4%BA%9A%E7%BA%B3/8252188?fromModule=lemma_inlink)；海外领地包括[关岛](https://baike.baidu.com/item/%E5%85%B3%E5%B2%9B/519630?fromModule=lemma_inlink)、[美属萨摩亚](https://baike.baidu.com/item/%E7%BE%8E%E5%B1%9E%E8%90%A8%E6%91%A9%E4%BA%9A/2938164?fromModule=lemma_inlink)、[美属维尔京群岛](https://baike.baidu.com/item/%E7%BE%8E%E5%B1%9E%E7%BB%B4%E5%B0%94%E4%BA%AC%E7%BE%A4%E5%B2%9B/3439863?fromModule=lemma_inlink)等，首都为华盛顿哥伦比亚特区。 [1] [6]<br />**美国各州州名及首府（按州名首字母排序）**

| **序号** |                                                              **州名**                                                               |     **英文**     | **简称** |                                                                    **首府**                                                                    |     **英文**     |
|--------|-----------------------------------------------------------------------------------------------------------------------------------|----------------|--------|----------------------------------------------------------------------------------------------------------------------------------------------|----------------|
| 1      | [**亚拉巴马州**](https://baike.baidu.com/item/%E4%BA%9A%E6%8B%89%E5%B7%B4%E9%A9%AC%E5%B7%9E/7052671?fromModule=lemma_inlink)           | Alabama        | AL     | [**蒙哥马利**](https://baike.baidu.com/item/%E8%92%99%E5%93%A5%E9%A9%AC%E5%88%A9/9638033?fromModule=lemma_inlink)                                | Montgomery     |
| 2      | [**阿拉斯加州**](https://baike.baidu.com/item/%E9%98%BF%E6%8B%89%E6%96%AF%E5%8A%A0%E5%B7%9E/1947146?fromModule=lemma_inlink)           | Alaska         | AK     | [**朱诺**](https://baike.baidu.com/item/%E6%9C%B1%E8%AF%BA/10416013?fromModule=lemma_inlink)                                                   | Juneau         |
| 3      | [**亚利桑那州**](https://baike.baidu.com/item/%E4%BA%9A%E5%88%A9%E6%A1%91%E9%82%A3%E5%B7%9E/2016570?fromModule=lemma_inlink)           | Arizona        | AZ     | [**菲尼克斯**](https://baike.baidu.com/item/%E8%8F%B2%E5%B0%BC%E5%85%8B%E6%96%AF/4856?fromModule=lemma_inlink)                                   | Phoenix        |
| 4      | [**阿肯色州**](https://baike.baidu.com/item/%E9%98%BF%E8%82%AF%E8%89%B2%E5%B7%9E/3436196?fromModule=lemma_inlink)                     | Arkansas       | AR     | [**小石城**](https://baike.baidu.com/item/%E5%B0%8F%E7%9F%B3%E5%9F%8E/5393602?fromModule=lemma_inlink)                                          | Little rock    |
| 5      | [**加利福尼亚州**](https://baike.baidu.com/item/%E5%8A%A0%E5%88%A9%E7%A6%8F%E5%B0%BC%E4%BA%9A%E5%B7%9E/40442?fromModule=lemma_inlink)   | California     | CA     | [**萨克拉门托**](https://baike.baidu.com/item/%E8%90%A8%E5%85%8B%E6%8B%89%E9%97%A8%E6%89%98/5404480?fromModule=lemma_inlink)                      | Sacramento     |
| 6      | [**科罗拉多州**](https://baike.baidu.com/item/%E7%A7%91%E7%BD%97%E6%8B%89%E5%A4%9A%E5%B7%9E/3288702?fromModule=lemma_inlink)           | Colorado       | CO     | [**丹佛**](https://baike.baidu.com/item/%E4%B8%B9%E4%BD%9B/2927494?fromModule=lemma_inlink)                                                    | Denver         |
| 7      | [**康涅狄格州**](https://baike.baidu.com/item/%E5%BA%B7%E6%B6%85%E7%8B%84%E6%A0%BC%E5%B7%9E/3436248?fromModule=lemma_inlink)           | Connecticut    | CT     | [**哈特福德**](https://baike.baidu.com/item/%E5%93%88%E7%89%B9%E7%A6%8F%E5%BE%B7/2007563?fromModule=lemma_inlink)                                | Hartford       |
| 8      | [**特拉华州**](https://baike.baidu.com/item/%E7%89%B9%E6%8B%89%E5%8D%8E%E5%B7%9E/3436266?fromModule=lemma_inlink)                     | Delaware       | DE     | [**多佛**](https://baike.baidu.com/item/%E5%A4%9A%E4%BD%9B/6059172?fromModule=lemma_inlink)                                                    | Dover          |
| 9      | [**佛罗里达州**](https://baike.baidu.com/item/%E4%BD%9B%E7%BD%97%E9%87%8C%E8%BE%BE%E5%B7%9E/3436285?fromModule=lemma_inlink)           | Florida        | FL     | [**塔拉哈西**](https://baike.baidu.com/item/%E5%A1%94%E6%8B%89%E5%93%88%E8%A5%BF/2004734?fromModule=lemma_inlink)                                | Tallahassee    |
| 10     | [**佐治亚州**](https://baike.baidu.com/item/%E4%BD%90%E6%B2%BB%E4%BA%9A%E5%B7%9E/1706352?fromModule=lemma_inlink)                     | Georgia        | GA     | [**亚特兰大**](https://baike.baidu.com/item/%E4%BA%9A%E7%89%B9%E5%85%B0%E5%A4%A7/11926?fromModule=lemma_inlink)                                  | Atlanta        |
| 11     | [**夏威夷州**](https://baike.baidu.com/item/%E5%A4%8F%E5%A8%81%E5%A4%B7%E5%B7%9E/3436297?fromModule=lemma_inlink)                     | Hawaii         | HI     | [**火奴鲁鲁**](https://baike.baidu.com/item/%E7%81%AB%E5%A5%B4%E9%B2%81%E9%B2%81/81317?fromModule=lemma_inlink)                                  | Honolulu       |
| 12     | [**爱达荷州**](https://baike.baidu.com/item/%E7%88%B1%E8%BE%BE%E8%8D%B7%E5%B7%9E/3436312?fromModule=lemma_inlink)                     | Idaho          | ID     | [**博伊西**](https://baike.baidu.com/item/%E5%8D%9A%E4%BC%8A%E8%A5%BF/3279458?fromModule=lemma_inlink)                                          | Boise          |
| 13     | [**伊利诺伊州**](https://baike.baidu.com/item/%E4%BC%8A%E5%88%A9%E8%AF%BA%E4%BC%8A%E5%B7%9E/3437724?fromModule=lemma_inlink)           | Illinois       | IL     | [**斯普林菲尔德**](https://baike.baidu.com/item/%E6%96%AF%E6%99%AE%E6%9E%97%E8%8F%B2%E5%B0%94%E5%BE%B7/1420017?fromModule=lemma_inlink)            | Springfield    |
| 14     | [**印第安纳州**](https://baike.baidu.com/item/%E5%8D%B0%E7%AC%AC%E5%AE%89%E7%BA%B3%E5%B7%9E/3437855?fromModule=lemma_inlink)           | Indiana        | IN     | [**印第安纳波利斯**](https://baike.baidu.com/item/%E5%8D%B0%E7%AC%AC%E5%AE%89%E7%BA%B3%E6%B3%A2%E5%88%A9%E6%96%AF/10473726?fromModule=lemma_inlink) | Indianapolis   |
| 15     | [**艾奥瓦州**](https://baike.baidu.com/item/%E8%89%BE%E5%A5%A5%E7%93%A6%E5%B7%9E/3437927?fromModule=lemma_inlink)                     | Iowa           | IA     | [**得梅因**](https://baike.baidu.com/item/%E5%BE%97%E6%A2%85%E5%9B%A0/3558622?fromModule=lemma_inlink)                                          | Des Moines     |
| 16     | [**堪萨斯州**](https://baike.baidu.com/item/%E5%A0%AA%E8%90%A8%E6%96%AF%E5%B7%9E/2874022?fromModule=lemma_inlink)                     | Kansas         | KS     | [**托皮卡**](https://baike.baidu.com/item/%E6%89%98%E7%9A%AE%E5%8D%A1/1162040?fromModule=lemma_inlink)                                          | Topeka         |
| 17     | [**肯塔基州**](https://baike.baidu.com/item/%E8%82%AF%E5%A1%94%E5%9F%BA%E5%B7%9E/3438094?fromModule=lemma_inlink)                     | Kentucky       | KY     | [**法兰克福**](https://baike.baidu.com/item/%E6%B3%95%E5%85%B0%E5%85%8B%E7%A6%8F/35351?fromModule=lemma_inlink)                                  | Frankfort      |
| 18     | [**路易斯安那州**](https://baike.baidu.com/item/%E8%B7%AF%E6%98%93%E6%96%AF%E5%AE%89%E9%82%A3%E5%B7%9E/2935061?fromModule=lemma_inlink) | Louisiana      | LA     | [**巴吞鲁日**](https://baike.baidu.com/item/%E5%B7%B4%E5%90%9E%E9%B2%81%E6%97%A5/10934876?fromModule=lemma_inlink)                               | Baton Rouge    |
| 19     | [**缅因州**](https://baike.baidu.com/item/%E7%BC%85%E5%9B%A0%E5%B7%9E/2683845?fromModule=lemma_inlink)                               | Maine          | ME     | [**奥古斯塔**](https://baike.baidu.com/item/%E5%A5%A5%E5%8F%A4%E6%96%AF%E5%A1%94/15920824?fromModule=lemma_inlink)                               | Augusta        |
| 20     | [**马里兰州**](https://baike.baidu.com/item/%E9%A9%AC%E9%87%8C%E5%85%B0%E5%B7%9E/3438236?fromModule=lemma_inlink)                     | Maryland       | MD     | [**安纳波利斯**](https://baike.baidu.com/item/%E5%AE%89%E7%BA%B3%E6%B3%A2%E5%88%A9%E6%96%AF/6463525?fromModule=lemma_inlink)                      | Annapolis      |
| 21     | [**马萨诸塞州**](https://baike.baidu.com/item/%E9%A9%AC%E8%90%A8%E8%AF%B8%E5%A1%9E%E5%B7%9E/3020558?fromModule=lemma_inlink)           | Massachusetts  | MA     | [**波士顿**](https://baike.baidu.com/item/%E6%B3%A2%E5%A3%AB%E9%A1%BF/81031?fromModule=lemma_inlink)                                            | Boston         |
| 22     | [**密歇根州**](https://baike.baidu.com/item/%E5%AF%86%E6%AD%87%E6%A0%B9%E5%B7%9E/3438465?fromModule=lemma_inlink)                     | Michigan       | MI     | [**兰辛**](https://baike.baidu.com/item/%E5%85%B0%E8%BE%9B/84503?fromModule=lemma_inlink)                                                      | Lansing        |
| 23     | [**明尼苏达州**](https://baike.baidu.com/item/%E6%98%8E%E5%B0%BC%E8%8B%8F%E8%BE%BE%E5%B7%9E/181052?fromModule=lemma_inlink)            | Minnesota      | MN     | [**圣保罗**](https://baike.baidu.com/item/%E5%9C%A3%E4%BF%9D%E7%BD%97/2827142?fromModule=lemma_inlink)                                          | St.Paul        |
| 24     | [**密西西比州**](https://baike.baidu.com/item/%E5%AF%86%E8%A5%BF%E8%A5%BF%E6%AF%94%E5%B7%9E/3438634?fromModule=lemma_inlink)           | Mississippi    | MS     | [**杰克逊**](https://baike.baidu.com/item/%E6%9D%B0%E5%85%8B%E9%80%8A/13236831?fromModule=lemma_inlink)                                         | Jackson        |
| 25     | [**密苏里州**](https://baike.baidu.com/item/%E5%AF%86%E8%8B%8F%E9%87%8C%E5%B7%9E/3438672?fromModule=lemma_inlink)                     | Missouri       | MO     | [**杰斐逊城**](https://baike.baidu.com/item/%E6%9D%B0%E6%96%90%E9%80%8A%E5%9F%8E/2449179?fromModule=lemma_inlink)                                | Jefferson City |
| 26     | [**蒙大拿州**](https://baike.baidu.com/item/%E8%92%99%E5%A4%A7%E6%8B%BF%E5%B7%9E/3438730?fromModule=lemma_inlink)                     | Montana        | MT     | [**海伦娜**](https://baike.baidu.com/item/%E6%B5%B7%E4%BC%A6%E5%A8%9C/13581136?fromModule=lemma_inlink)                                         | Helena         |
| 27     | [**内布拉斯加州**](https://baike.baidu.com/item/%E5%86%85%E5%B8%83%E6%8B%89%E6%96%AF%E5%8A%A0%E5%B7%9E/2217761?fromModule=lemma_inlink) | Nebraska       | NE     | 林肯                                                                                                                                           | Lincoln        |
| 28     | [**内华达州**](https://baike.baidu.com/item/%E5%86%85%E5%8D%8E%E8%BE%BE%E5%B7%9E/2874107?fromModule=lemma_inlink)                     | Nevada         | NV     | [**卡森城**](https://baike.baidu.com/item/%E5%8D%A1%E6%A3%AE%E5%9F%8E/11001834?fromModule=lemma_inlink)                                         | Carson City    |
| 29     | [**新罕布什尔州**](https://baike.baidu.com/item/%E6%96%B0%E7%BD%95%E5%B8%83%E4%BB%80%E5%B0%94%E5%B7%9E/3438824?fromModule=lemma_inlink) | New Hampshire  | NH     | [**康科德**](https://baike.baidu.com/item/%E5%BA%B7%E7%A7%91%E5%BE%B7/84534?fromModule=lemma_inlink)                                            | Concord        |
| 30     | [**新泽西州**](https://baike.baidu.com/item/%E6%96%B0%E6%B3%BD%E8%A5%BF%E5%B7%9E/3438878?fromModule=lemma_inlink)                     | New Jersey     | NJ     | [**特伦顿**](https://baike.baidu.com/item/%E7%89%B9%E4%BC%A6%E9%A1%BF/1988236?fromModule=lemma_inlink)                                          | Trenton        |
| 31     | [**新墨西哥州**](https://baike.baidu.com/item/%E6%96%B0%E5%A2%A8%E8%A5%BF%E5%93%A5%E5%B7%9E/3438975?fromModule=lemma_inlink)           | New Mexico     | NM     | [**圣菲**](https://baike.baidu.com/item/%E5%9C%A3%E8%8F%B2/84537?fromModule=lemma_inlink)                                                      | Santa Fe       |
| 32     | [**纽约州**](https://baike.baidu.com/item/%E7%BA%BD%E7%BA%A6%E5%B7%9E/3439049?fromModule=lemma_inlink)                               | New York       | NY     | [**奥尔巴尼**](https://baike.baidu.com/item/%E5%A5%A5%E5%B0%94%E5%B7%B4%E5%B0%BC/84536?fromModule=lemma_inlink)                                  | Albany         |
| 33     | [**北卡罗来纳州**](https://baike.baidu.com/item/%E5%8C%97%E5%8D%A1%E7%BD%97%E6%9D%A5%E7%BA%B3%E5%B7%9E/3439107?fromModule=lemma_inlink) | North Carolina | NC     | [**纳罗利**](https://baike.baidu.com/item/%E7%BA%B3%E7%BD%97%E5%88%A9/5233584?fromModule=lemma_inlink)                                          | Raleigh        |
| 34     | [**北达科他州**](https://baike.baidu.com/item/%E5%8C%97%E8%BE%BE%E7%A7%91%E4%BB%96%E5%B7%9E/3439163?fromModule=lemma_inlink)           | North Dakota   | ND     | [**俾斯麦**](https://baike.baidu.com/item/%E4%BF%BE%E6%96%AF%E9%BA%A6/2225298?fromModule=lemma_inlink)                                          | Bismarck       |
| 35     | [**俄亥俄州**](https://baike.baidu.com/item/%E4%BF%84%E4%BA%A5%E4%BF%84%E5%B7%9E/3439219?fromModule=lemma_inlink)                     | Ohio           | OH     | [**哥伦布**](https://baike.baidu.com/item/%E5%93%A5%E4%BC%A6%E5%B8%83/9657567?fromModule=lemma_inlink)                                          | Columbus       |
| 36     | [**俄克拉何马州**](https://baike.baidu.com/item/%E4%BF%84%E5%85%8B%E6%8B%89%E4%BD%95%E9%A9%AC%E5%B7%9E/3439257?fromModule=lemma_inlink) | Oklahoma       | OK     | [**俄克拉何马城**](https://baike.baidu.com/item/%E4%BF%84%E5%85%8B%E6%8B%89%E4%BD%95%E9%A9%AC%E5%9F%8E/9863244?fromModule=lemma_inlink)            | Oklahoma City  |
| 37     | [**俄勒冈州**](https://baike.baidu.com/item/%E4%BF%84%E5%8B%92%E5%86%88%E5%B7%9E/3439295?fromModule=lemma_inlink)                     | Oregon         | OR     | [**塞勒姆**](https://baike.baidu.com/item/%E5%A1%9E%E5%8B%92%E5%A7%86/18640702?fromModule=lemma_inlink)                                         | Salem          |
| 38     | [**宾夕法尼亚州**](https://baike.baidu.com/item/%E5%AE%BE%E5%A4%95%E6%B3%95%E5%B0%BC%E4%BA%9A%E5%B7%9E/5148?fromModule=lemma_inlink)    | Pennsylvania   | PA     | [**哈里斯堡**](https://baike.baidu.com/item/%E5%93%88%E9%87%8C%E6%96%AF%E5%A0%A1/1973648?fromModule=lemma_inlink)                                | Harrisburg     |
| 39     | [**罗得岛州**](https://baike.baidu.com/item/%E7%BD%97%E5%BE%97%E5%B2%9B%E5%B7%9E/3439332?fromModule=lemma_inlink)                     | Rhode Island   | RI     | [**普罗维登斯**](https://baike.baidu.com/item/%E6%99%AE%E7%BD%97%E7%BB%B4%E7%99%BB%E6%96%AF/2014124?fromModule=lemma_inlink)                      | Providence     |
| 40     | [**南卡罗来纳州**](https://baike.baidu.com/item/%E5%8D%97%E5%8D%A1%E7%BD%97%E6%9D%A5%E7%BA%B3%E5%B7%9E/7363647?fromModule=lemma_inlink) | South Carolina | SC     | [**哥伦比亚**](https://baike.baidu.com/item/%E5%93%A5%E4%BC%A6%E6%AF%94%E4%BA%9A/6561398?fromModule=lemma_inlink)                                | Columbia       |
| 41     | [**南达科他州**](https://baike.baidu.com/item/%E5%8D%97%E8%BE%BE%E7%A7%91%E4%BB%96%E5%B7%9E/3439373?fromModule=lemma_inlink)           | South Dakota   | SD     | [**皮尔**](https://baike.baidu.com/item/%E7%9A%AE%E5%B0%94/17490571?fromModule=lemma_inlink)                                                   | Pierre         |
| 42     | [**田纳西州**](https://baike.baidu.com/item/%E7%94%B0%E7%BA%B3%E8%A5%BF%E5%B7%9E/3439391?fromModule=lemma_inlink)                     | Tennessee      | TN     | [**纳什维尔**](https://baike.baidu.com/item/%E7%BA%B3%E4%BB%80%E7%BB%B4%E5%B0%94/26068?fromModule=lemma_inlink)                                  | Nashville      |
| 43     | [**得克萨斯州**](https://baike.baidu.com/item/%E5%BE%97%E5%85%8B%E8%90%A8%E6%96%AF%E5%B7%9E/3439412?fromModule=lemma_inlink)           | Texas          | TX     | [**奥斯汀**](https://baike.baidu.com/item/%E5%A5%A5%E6%96%AF%E6%B1%80/15484?fromModule=lemma_inlink)                                            | Austin         |
| 44     | [**犹他州**](https://baike.baidu.com/item/%E7%8A%B9%E4%BB%96%E5%B7%9E/3439429?fromModule=lemma_inlink)                               | Utah           | UT     | [**盐湖城**](https://baike.baidu.com/item/%E7%9B%90%E6%B9%96%E5%9F%8E/8808871?fromModule=lemma_inlink)                                          | Salt Lake City |
| 45     | [**佛蒙特州**](https://baike.baidu.com/item/%E4%BD%9B%E8%92%99%E7%89%B9%E5%B7%9E/3439446?fromModule=lemma_inlink)                     | Vermont        | VT     | [**蒙彼利埃**](https://baike.baidu.com/item/%E8%92%99%E5%BD%BC%E5%88%A9%E5%9F%83/8939524?fromModule=lemma_inlink)                                | Montpelier     |
| 46     | [**弗吉尼亚州**](https://baike.baidu.com/item/%E5%BC%97%E5%90%89%E5%B0%BC%E4%BA%9A%E5%B7%9E/3439466?fromModule=lemma_inlink)           | Virginia       | VA     | [**里士满**](https://baike.baidu.com/item/%E9%87%8C%E5%A3%AB%E6%BB%A1/964714?fromModule=lemma_inlink)                                           | Richmond       |
| 47     | [**华盛顿州**](https://baike.baidu.com/item/%E5%8D%8E%E7%9B%9B%E9%A1%BF%E5%B7%9E/2220710?fromModule=lemma_inlink)                     | Washington     | WA     | [**奥林匹亚**](https://baike.baidu.com/item/%E5%A5%A5%E6%9E%97%E5%8C%B9%E4%BA%9A/6379216?fromModule=lemma_inlink)                                | Olympia        |
| 48     | [**西弗吉尼亚州**](https://baike.baidu.com/item/%E8%A5%BF%E5%BC%97%E5%90%89%E5%B0%BC%E4%BA%9A%E5%B7%9E/2873912?fromModule=lemma_inlink) | West Virginia  | WV     | [**查尔斯顿**](https://baike.baidu.com/item/%E6%9F%A5%E5%B0%94%E6%96%AF%E9%A1%BF/1761052?fromModule=lemma_inlink)                                | Charleston     |
| 49     | [**威斯康星州**](https://baike.baidu.com/item/%E5%A8%81%E6%96%AF%E5%BA%B7%E6%98%9F%E5%B7%9E/7052558?fromModule=lemma_inlink)           | Wisconsin      | WI     | [**麦迪逊**](https://baike.baidu.com/item/%E9%BA%A6%E8%BF%AA%E9%80%8A/3692324?fromModule=lemma_inlink)                                          | Madison        |
| 50     | [**怀俄明州**](https://baike.baidu.com/item/%E6%80%80%E4%BF%84%E6%98%8E%E5%B7%9E/3439543?fromModule=lemma_inlink)                     | Wyoming        | WY     | [**夏延**](https://baike.baidu.com/item/%E5%A4%8F%E5%BB%B6/1167577?fromModule=lemma_inlink)                                                    | Cheyenne       |

<a name="aHRli"></a>

## 1.2、经济

<a name="QxbDE"></a>

### 1.2.1、对外贸易

美国主要出口商品为：汽车、大豆、精炼石油、飞行器、原油、集成电路等。主要进口商品是：汽车、原油、广播设备、计算机、汽车零件等。<br />2022年美国前五大货物贸易伙伴为加拿大、墨西哥、中国、日本、德国。美国前五大货物出口市场为加拿大、墨西哥、中国、日本、英国。美国前五大货物进口来源地为中国、墨西哥、加拿大、日本、德国。<br />2022年，美国商品和服务贸易进口额39578亿美元、同比增长16.3％，出口额30097亿美元、同比增长17.7％，贸易逆差9481亿美元、同比扩大12.2％。 [1]<br />**近年美国对外贸易情况（单位：亿美元）**

